from .Consent_screen_check import WebConsentChecker
from .Content_moderation_filter_check import ContentModerationChecker
from .Data_minimization_checker import DataMinimizationChecker
from .grievance_extractor import GrievanceExtractor
from .grivance_redressal_checker import GrievanceRedressalChecker
from .Dark_patterns_check import DarkPatternsChecker
from .privacy_policy import PrivacyPolicyChecker
from .fairness_detect import run_basic_fairness_detect
from .fairness_detect import run_advance_fairness_detect
from .fairness_detect_diff import run_fairness_by_prompt
