API_OPENNESS_RULES = {
    "API-OPEN-1": "OpenAPI / Swagger specification present",
    "API-OPEN-2": "RESTful HTTP methods used correctly",
    "API-OPEN-3": "API versioning present",
    "API-OPEN-4": "JSON used as response format",
    "API-OPEN-5": "Authentication enforced",
}